import { derive } from './derive.js';
import { parse_x, normalize_x } from './utils.js';
export declare const noble: {
    secp: Readonly<{
        create: (hash: import("@noble/curves/abstract/utils.js").CHash) => import("@noble/curves/abstract/weierstrass.js").CurveFn;
        CURVE: Readonly<{
            readonly nBitLength: number;
            readonly nByteLength: number;
            readonly Fp: import("@noble/curves/abstract/modular.js").IField<bigint>;
            readonly n: bigint;
            readonly h: bigint;
            readonly hEff?: bigint | undefined;
            readonly Gx: bigint;
            readonly Gy: bigint;
            readonly allowInfinityPoint?: boolean | undefined;
            readonly a: bigint;
            readonly b: bigint;
            readonly allowedPrivateKeyLengths?: readonly number[] | undefined;
            readonly wrapPrivateKey?: boolean | undefined;
            readonly endo?: {
                beta: bigint;
                splitScalar: (k: bigint) => {
                    k1neg: boolean;
                    k1: bigint;
                    k2neg: boolean;
                    k2: bigint;
                };
            } | undefined;
            readonly isTorsionFree?: ((c: import("@noble/curves/abstract/weierstrass.js").ProjConstructor<bigint>, point: import("@noble/curves/abstract/weierstrass.js").ProjPointType<bigint>) => boolean) | undefined;
            readonly clearCofactor?: ((c: import("@noble/curves/abstract/weierstrass.js").ProjConstructor<bigint>, point: import("@noble/curves/abstract/weierstrass.js").ProjPointType<bigint>) => import("@noble/curves/abstract/weierstrass.js").ProjPointType<bigint>) | undefined;
            readonly hash: import("@noble/curves/abstract/utils.js").CHash;
            readonly hmac: (key: Uint8Array, ...messages: Uint8Array[]) => Uint8Array;
            readonly randomBytes: (bytesLength?: number | undefined) => Uint8Array;
            lowS: boolean;
            readonly bits2int?: ((bytes: Uint8Array) => bigint) | undefined;
            readonly bits2int_modN?: ((bytes: Uint8Array) => bigint) | undefined;
            readonly p: bigint;
        }>;
        getPublicKey: (privateKey: import("@noble/curves/abstract/utils.js").PrivKey, isCompressed?: boolean | undefined) => Uint8Array;
        getSharedSecret: (privateA: import("@noble/curves/abstract/utils.js").PrivKey, publicB: import("@noble/curves/abstract/utils.js").Hex, isCompressed?: boolean | undefined) => Uint8Array;
        sign: (msgHash: import("@noble/curves/abstract/utils.js").Hex, privKey: import("@noble/curves/abstract/utils.js").PrivKey, opts?: import("@noble/curves/abstract/weierstrass.js").SignOpts | undefined) => import("@noble/curves/abstract/weierstrass.js").SignatureType;
        verify: (signature: import("@noble/curves/abstract/utils.js").Hex | {
            r: bigint;
            s: bigint;
        }, msgHash: import("@noble/curves/abstract/utils.js").Hex, publicKey: import("@noble/curves/abstract/utils.js").Hex, opts?: import("@noble/curves/abstract/weierstrass.js").VerOpts | undefined) => boolean;
        ProjectivePoint: import("@noble/curves/abstract/weierstrass.js").ProjConstructor<bigint>;
        Signature: import("@noble/curves/abstract/weierstrass.js").SignatureConstructor;
        utils: {
            normPrivateKeyToScalar: (key: import("@noble/curves/abstract/utils.js").PrivKey) => bigint;
            isValidPrivateKey(privateKey: import("@noble/curves/abstract/utils.js").PrivKey): boolean;
            randomPrivateKey: () => Uint8Array;
            precompute: (windowSize?: number | undefined, point?: import("@noble/curves/abstract/weierstrass.js").ProjPointType<bigint> | undefined) => import("@noble/curves/abstract/weierstrass.js").ProjPointType<bigint>;
        };
    }>;
    schnorr: {
        getPublicKey: (privateKey: import("@noble/curves/abstract/utils.js").Hex) => Uint8Array;
        sign: (message: import("@noble/curves/abstract/utils.js").Hex, privateKey: import("@noble/curves/abstract/utils.js").PrivKey, auxRand?: import("@noble/curves/abstract/utils.js").Hex | undefined) => Uint8Array;
        verify: (signature: import("@noble/curves/abstract/utils.js").Hex, message: import("@noble/curves/abstract/utils.js").Hex, publicKey: import("@noble/curves/abstract/utils.js").Hex) => boolean;
        utils: {
            randomPrivateKey: () => Uint8Array;
            lift_x: (x: bigint) => import("@noble/curves/abstract/weierstrass.js").ProjPointType<bigint>;
            pointToBytes: (point: import("@noble/curves/abstract/weierstrass.js").ProjPointType<bigint>) => Uint8Array;
            numberToBytesBE: (n: bigint, len: number) => Uint8Array;
            bytesToNumberBE: typeof import("@noble/curves/abstract/utils.js").bytesToNumberBE;
            taggedHash: (tag: string, ...messages: Uint8Array[]) => Uint8Array;
            mod: typeof import("@noble/curves/abstract/modular.js").mod;
        };
    };
};
export * from './config.js';
export * from './ecc.js';
export * from './hash.js';
export * from './types.js';
export * as assert from './assert.js';
export * as ecdh from './ecdh.js';
export * as math from './math.js';
export * as point from './point.js';
export * as util from './utils.js';
export declare const ecc: {
    derive: typeof derive;
    parse_x: typeof parse_x;
    normalize_x: typeof normalize_x;
    sign(message: import("@cmdcode/buff-utils").Bytes, secret: import("@cmdcode/buff-utils").Bytes, config?: Partial<import("./config.js").SignerOptions> | undefined): import("@cmdcode/buff-utils").Buff;
    verify(signature: import("@cmdcode/buff-utils").Bytes, message: import("@cmdcode/buff-utils").Bytes, pubkey: import("@cmdcode/buff-utils").Bytes, config?: Partial<import("./config.js").SignerOptions> | undefined): boolean;
    recover(signature: import("@cmdcode/buff-utils").Bytes, message: import("@cmdcode/buff-utils").Bytes, pub_key: import("@cmdcode/buff-utils").Bytes, rec_key: import("@cmdcode/buff-utils").Bytes): import("@cmdcode/buff-utils").Buff;
    is_even_pub(pubkey: import("@cmdcode/buff-utils").Bytes): boolean;
    gen_seckey(even_y?: boolean | undefined): import("@cmdcode/buff-utils").Buff;
    get_seckey(secret: import("@cmdcode/buff-utils").Bytes, even_y?: boolean): import("@cmdcode/buff-utils").Buff;
    get_pubkey(seckey: import("@cmdcode/buff-utils").Bytes, xonly?: boolean): import("@cmdcode/buff-utils").Buff;
    get_keypair(secret: import("@cmdcode/buff-utils").Bytes, xonly?: boolean | undefined, even_y?: boolean | undefined): [import("@cmdcode/buff-utils").Buff, import("@cmdcode/buff-utils").Buff];
    gen_keypair(xonly?: boolean | undefined, even_y?: boolean | undefined): [import("@cmdcode/buff-utils").Buff, import("@cmdcode/buff-utils").Buff];
};
//# sourceMappingURL=index.d.ts.map